
/**
 * Class for bank (savings) accounts supporting deposit,
 * withdraw, balance inquiry, and transaction monitoring.
 * 
 * @author JP Vergara 
 * @version 1.0
 */
public class CheckingAccount
{
    // Each bank accountobject stores a balance
    private double balance;
    // transactions need to be counted
    private int transactionCount;
    
    // transaction free limit and transaction fee
    private static final int FREE_TRANSACTIONS = 3;
    private static final double TRANSACTION_FEE = 2.00;

    /**
     * Constructor for objects of class CheckingAccount
     */
    public CheckingAccount()
    {
        balance = 0;
        transactionCount = 0;
    }

    /**
     * Constructor for objects of class CheckingAccount,
     * where an initial balance is specified
     * 
     * @param initBal  initial balance
     */
    public CheckingAccount( double initBal )
    {
        balance = initBal;
        transactionCount = 0;
    }

    /**
     * Deposits some amount into the account
     * 
     * @param amount  amount to be deposited
     */
    public void deposit( double amount )
    {
        transactionCount++;
        balance = balance + amount;
    }

    /**
     * Withdraws some amount from the account
     * 
     * @param amount  amount to be withdrawn
     */
    public void withdraw( double amount )
    {
        transactionCount++;
        if ( amount <= balance )
        {
            balance = balance - amount;
        }
        else
        {
            System.out.println( "Insufficient balance" );
        }
    }

    /**
     * Get the current balance
     * 
     * @return  current balance 
     */
    public double getBalance( )
    {
        return balance;
    }
    
    /**
     * Deducts the accumulated fees
     * and resets transaction count
     * 
     */
    
    public void deductFees()
    {
        if ( transactionCount > FREE_TRANSACTIONS )
        {
            double fees = TRANSACTION_FEE * (transactionCount - FREE_TRANSACTIONS);
            balance = balance - fees; // or withdraw( fees );
        }
        transactionCount = 0;
    }

}
